@@ -56,22 +56,18 @@ define('PRODUCTS_PREF_DFLTSEARCH_TEMPLATE','products_pref_dfltsearch_template');
 
 final class Products extends CGExtensions
 {
-  var $_admin_loaded;
+  private $_admin_loaded;
 
   public function __construct()
   {
     parent::__construct();
 	$this->_admin_loaded = false;
-
 	$this->AddImageDir('icons');
 
     $smarty = cmsms()->GetSmarty();
-	$smarty->register_function('products_getcategory',
-							   array($this,'_smarty_products_getcategory'));
-	$smarty->register_function('products_hierarchy_breadcrumb',
-							   array($this,'_smarty_products_hierarchy_breadcrumb'));
-	$smarty->register_function('products_hierarchy_parent',
-							   array($this,'_smarty_products_hierarchy_parent'));
+	$smarty->register_function('products_getcategory',array($this,'_smarty_products_getcategory'));
+	$smarty->register_function('products_hierarchy_breadcrumb',array($this,'_smarty_products_hierarchy_breadcrumb'));
+	$smarty->register_function('products_hierarchy_parent',array($this,'_smarty_products_hierarchy_parent'));
   }
 
   public function GetName() { return 'Products'; }
@@ -80,8 +76,8 @@ final class Products extends CGExtensions
   public function AllowAutoUpgrade() { return FALSE; }
   public function IsPluginModule() { return true; }
   public function HasAdmin() {	return true; }
-  public function GetVersion() { return '2.19.4'; }
-  public function MinimumCMSVersion() { return '1.11.4'; }
+  public function GetVersion() { return '2.19.8'; }
+  public function MinimumCMSVersion() { return '1.11.8'; }
   public function GetAdminDescription() { return $this->Lang('module_description'); }
   public function UninstallPostMessage() { return $this->Lang('postuninstall'); }
   public function UninstallPreMessage() { return $this->Lang('preuninstall'); }
@@ -220,16 +216,12 @@ EOT;
 	if( $this->GetPreference('usehierpathurls') ) {
 	  $this->RegisterRoute($str.'\/details\/(?P<returnid>[0-9]+)\/([^\/]+\/)+(?P<alias>.*)$/',
 						   array('action'=>'details','returnid'=>$detailpage));
-	  $this->RegisterRoute($str.'\/details\/([^\/]+\/)+(?P<alias>.*)$/',
-						   array('action'=>'details','returnid'=>$detailpage));
+	  $this->RegisterRoute($str.'\/details\/([^\/]+\/)+(?P<alias>.*)$/',array('action'=>'details','returnid'=>$detailpage));
 	}
 
-	$this->RegisterRoute($str.'\/(?P<productid>[0-9]+)\/(?P<returnid>[0-9]+)\/(?P<junk>.*?)$/',
-						 array('action'=>'details'));
-	$this->RegisterRoute($str.'\/(?P<productid>[0-9]+)\/(?P<junk>.*?)$/',
-						 array('action'=>'details','returnid'=>$detailpage));
-	$this->RegisterRoute($str.'\/viewcategory\/(?P<categoryid>[0-9]+)\/(?P<returnid>[0-9]+)$/',
-						 array('action'=>'categorylist'));
+	$this->RegisterRoute($str.'\/(?P<productid>[0-9]+)\/(?P<returnid>[0-9]+)\/(?P<junk>.*?)$/',array('action'=>'details'));
+	$this->RegisterRoute($str.'\/(?P<productid>[0-9]+)\/(?P<junk>.*?)$/', array('action'=>'details','returnid'=>$detailpage));
+	$this->RegisterRoute($str.'\/viewcategory\/(?P<categoryid>[0-9]+)\/(?P<returnid>[0-9]+)$/',array('action'=>'categorylist'));
 	$this->RegisterRoute($str.'\/(?P<productid>[0-9]+)$/');
 	$this->RegisterRoute($str.'\/summary\/($P<returnid>[0-9]+)\/(?P<junk>.*?)$/');
 	$this->RegisterRoute($str.'\/summary\/($P<returnid>[0-9]+)$/');
@@ -239,9 +231,7 @@ EOT;
 	$this->RegisterRoute($str.'\/byhierarchy\/(?P<hierarchyid>[0-9]+)\/(?P<returnid>[0-9]+)$/');
 
 	$hierpage = $this->GetPreference('hierpage',-1);
-	if( $hierpage <= 0 ) {
-	  $hierpage = $detailpage;
-	}
+	if( $hierpage <= 0 ) $hierpage = $detailpage;
 	$this->RegisterRoute($str.'\/hierarchy\/(?P<parent>[0-9]+)\/(?P<returnid>[0-9]+)$/');
 	$this->RegisterRoute($str.'\/hierarchy\/(?P<parent>[0-9]+)\/(?P<returnid>[0-9]+)\/(?P<junk>.*?)$/');
 	$this->RegisterRoute($str.'\/hierarchy\/(?P<parent>[0-9]+)\/(?P<junk>.*?)$/',
@@ -294,9 +284,7 @@ EOT;
 
 	if( $full ) {
 	  $tmp2 = $db->GetArray($query2,$row['id']);
-	  if( is_array($tmp2) ) {
-		$onerow->data = $tmp2;
-	  }
+	  if( is_array($tmp2) ) $onerow->data = $tmp2;
 	}
 
 	return $onerow;
@@ -334,7 +322,7 @@ EOT;
 		}
 	  }
 	}
-	else {
+	else if( is_array($entryarray) && count($entryarray) ) {
 	  // full list of categories,
 	  // set value to true if this product is a member of this category
 	  foreach( $entryarray as $entry ) {
@@ -363,7 +351,7 @@ EOT;
   {
 	$gCms = cmsms();
 	$db = $gCms->GetDB();
-		
+
 	$entryarray = $this->GetFieldDefs($admin,$public);
 
 	$query = '';
@@ -385,9 +373,7 @@ EOT;
 	    $newentry->value = null;
 	    foreach ($dbresult as $row) {
 		  if ($row['fielddef_id'] == $newentry->id) {
-			if( $newentry->type == 'dimensions' || $newentry->type == 'subscription') {
-			  $row['value'] = unserialize($row['value']);
-			}
+			if( $newentry->type == 'dimensions' || $newentry->type == 'subscription') $row['value'] = unserialize($row['value']);
 			$newentry->value = $row['value'];
 			$newentry->fielddef_id = $newentry->id; // ??
 			break;
@@ -411,14 +397,19 @@ EOT;
 	return products_SearchReindex($this,$module);
   }
 
-  // deprecated ... move to class
-  protected function GetSearchableText($product_id)
+  public function GetSearchableText($product_id)
   {
-	// the product name, the description, and all data from
-	// text fields, textara fields, and dropdowns
-	$product = product_ops::get_product($product_id);
+	$product = null;
+	if( is_array($product_id) && isset($product_id['id']) ) {
+	  $product = $product_id;
+	}
+	else if( (int)$product_id > 0 ) {
+	  // the product name, the description, and all data from
+	  // text fields, textara fields, and dropdowns
+	  $product = product_ops::get_product($product_id);
+	}
 	if( $product['status'] != 'published' ) return array();
-	$defs = $this->GetFieldDefsForProduct($product_id);
+	$defs = $this->GetFieldDefsForProduct($product['id']);
 
 	$results = array();
 	$results[] = $product['product_name'];
@@ -430,9 +421,7 @@ EOT;
 	  case 'textbox':
 	  case 'textarea':
 	  case 'dropdown':
-		if( isset($onedef->value) ) {
-		  $results[] = $onedef->value;
-		}
+		if( isset($onedef->value) ) $results[] = $onedef->value;
 		break;
 	  }
 	}
@@ -487,9 +476,7 @@ EOT;
   {
 	if( empty($hier_str) ) return FALSE;
 	$hier_str = trim($hier_str);
-	if( $delim != ' | ' ) {
-	  $hier_str = str_replace($delim,' | ',$hier_str);
-	}
+	if( $delim != ' | ' ) $hier_str = str_replace($delim,' | ',$hier_str);
 	
 	$gCms = cmsms();
 	$db = $gCms->GetDb();
@@ -566,9 +553,7 @@ EOT;
 		  $prettyurl = sprintf("%s/bycategory/%d/%d",
 							   $this->GetPreference('urlprefix','products'),
 							   (int)$params['categoryid'],$returnid);
-		  if( isset($params['categoryname']) ) {
-			$prettyurl .= '/'.munge_string_to_url($params['categoryname']);
-		  }
+		  if( isset($params['categoryname']) ) $prettyurl .= '/'.munge_string_to_url($params['categoryname']);
 		}
 		else if( isset($params['hierarchyid']) ) {
 		  // if the hierarchy id parameter is set, use byhierarchy
@@ -589,12 +574,10 @@ EOT;
 		break;
 
 	  case 'categorylist':
-		{
-		  if( isset($params['categoryid']) && !isset($params['categorylistdtltemplate']) ) {
-			$prettyurl = sprintf("%s/viewcategory/%s/%s",
-								 $this->GetPreference('urlprefix','products'),
-								 (int)$params['categoryid'],$returnid);
-		  }
+		if( isset($params['categoryid']) && !isset($params['categorylistdtltemplate']) ) {
+		  $prettyurl = sprintf("%s/viewcategory/%s/%s",
+							   $this->GetPreference('urlprefix','products'),
+							   (int)$params['categoryid'],$returnid);
 		}
 		break;
 
@@ -609,11 +592,7 @@ EOT;
 		if( $this->GetPreference('prettyhierurls',0) ) {
 		  // add the name to the url.
 		  $info = hierarchy_ops::get_hierarchy_info($params['parent']);
-		  if( is_array($info) ) {
-			{
-			  $prettyurl .= '/'.munge_string_to_url($info['name']);
-			}
-		  }
+		  if( is_array($info) ) $prettyurl .= '/'.munge_string_to_url($info['name']);
 		}
 		break;
 	  } // switch
@@ -689,9 +668,7 @@ EOT;
 	  if( $tmp ) $returnid = $tmp;
 	}
 	$delim = ' &raquo ';
-	if( isset($params['delim']) ) {
-	  $delim = $params['delim'];
-	}
+	if( isset($params['delim']) ) $delim = $params['delim'];
 
 	$hierid = (int)$params['hierarchyid'];
 	$bc = hierarchy_ops::get_breadcrumb('prod',$hierid,$returnid,$delim);
@@ -720,12 +697,10 @@ EOT;
   function get_product_info($product_id)
   {
 	$tmp = product_ops::get_product($product_id);
-	if( !is_array($tmp) ) {
-	  return FALSE;
-	}
+	if( !is_array($tmp) ) return FALSE;
 	return $tmp;
   }
 } // class
 
 # vim:ts=4 sw=4 noet
-?>
\ No newline at end of file
+?>
