@@ -59,6 +59,16 @@ if( $data['image'] )
       {
 	@unlink($fn);
       }
+    $fn = cms_join_path($destdir,'thumb_'.$data['image']);
+    if( @file_exists($fn) )
+      {
+	@unlink($fn);
+      }
+    $fn = cms_join_path($destdir,'preview_'.$data['image']);
+    if( @file_exists($fn) )
+      {
+	@unlink($fn);
+      }
   }
 
 // reset all peer hierarchies item order
@@ -77,7 +87,7 @@ $db->Execute( $query, array( $hierarchy_id ) );
 
 // And now update any products to have no category
 // if they have this hierarchy_id
-$query = 'DELETE FROM '.cms_db_prefix().'module_products_prodtoheir
+$query = 'DELETE FROM '.cms_db_prefix().'module_products_prodtohier
            WHERE hierarchy_id = ?';
 $db->Execute( $query, array( $hierarchy_id ) );
 
