@@ -39,9 +39,7 @@
 if (!isset($gCms)) exit;
 
 $thetemplate = 'summary_'.$this->GetPreference(PRODUCTS_PREF_DFLTSUMMARY_TEMPLATE);
-if( isset($params['summarytemplate'] ) ) {
-  $thetemplate = 'summary_'.$params['summarytemplate'];
-}
+if( isset($params['summarytemplate'] ) ) $thetemplate = 'summary_'.$params['summarytemplate'];
 
 $cache_id = '|ps'.md5(serialize($params));
 $compile_id = '';
@@ -61,12 +59,9 @@ if( !$smarty->isCached($this->GetDatabaseResource($thetemplate),$cache_id,$compi
 
     $results = new products_resultset($query);
     $results->curpage = $returnid;
-    if( isset($params['notpretty']) ) {
-      $results->notpretty = $params['notpretty'];
-    }
-    if( isset($params['detailpage']) ) {
-      $results->detailpage = $params['detailpage'];
-    }
+    if( isset($params['notpretty']) ) $results->notpretty = $params['notpretty'];
+    if( isset($params['detailpage']) ) $results->detailpage = $params['detailpage'];
+    if( isset($params['detailtemplate']) ) $results->detailtemplate = $params['detailtemplate'];
     $entryarray = array();
     while( !$results->EOF ) {
       $entryarray[] = $results->get_product_for_display();
@@ -76,6 +71,7 @@ if( !$smarty->isCached($this->GetDatabaseResource($thetemplate),$cache_id,$compi
     //
     // give everything to smarty
     //
+    if( isset($query['hierarchyid']) ) $smarty->assign('active_hierarchy',$query['hierarchyid']);
     $smarty->assign('items',$entryarray);
     $smarty->assign('itemcount',count($entryarray));
     $smarty->assign('totalcount',$results->totalrows);
@@ -88,15 +84,11 @@ if( !$smarty->isCached($this->GetDatabaseResource($thetemplate),$cache_id,$compi
     } else {
       $parms = $params;
       $parms['page'] = 1;
-      $smarty->assign('firstlink',$this->CreateLink($id,'default',$returnid,
-						    $this->Lang('firstpage'),
-						    $parms));
+      $smarty->assign('firstlink',$this->CreateLink($id,'default',$returnid,$this->Lang('firstpage'),$parms));
       $smarty->assign('firstpage_url',$this->create_url($id,'default',$returnid,$parms));
 
       $parms['page'] = $page - 1;
-      $smarty->assign('prevlink',$this->CreateLink($id,'default',$returnid,
-						   $this->Lang('prevpage'),
-						   $parms));
+      $smarty->assign('prevlink',$this->CreateLink($id,'default',$returnid,$this->Lang('prevpage'),$parms));
       $smarty->assign('prevpage_url',$this->create_url($id,'default',$returnid,$parms));
     }
   
@@ -106,14 +98,10 @@ if( !$smarty->isCached($this->GetDatabaseResource($thetemplate),$cache_id,$compi
     } else {
       $parms = $params;
       $parms['page'] = $results->numpages;
-      $smarty->assign('lastlink',$this->CreateLink($id,'default',$returnid,
-						   $this->Lang('lastpage'),
-						   $parms));
+      $smarty->assign('lastlink',$this->CreateLink($id,'default',$returnid,$this->Lang('lastpage'),$parms));
       $smarty->assign('lastpage_url',$this->create_url($id,'default',$returnid,$parms));
       $parms['page'] = $page + 1;
-      $smarty->assign('nextlink',$this->CreateLink($id,'default',$returnid,
-						   $this->Lang('nextpage'),
-						   $parms));
+      $smarty->assign('nextlink',$this->CreateLink($id,'default',$returnid,$this->Lang('nextpage'),$parms));
       $smarty->assign('nextpage_url',$this->create_url($id,'default',$returnid,$parms));
     }
 
