@@ -84,9 +84,9 @@ $query = "DELETE FROM ".cms_db_prefix()."module_products_categories WHERE id = ?
 $db->Execute($query, array($catid));
 
 //And remove it from any entries
-$query = "DELETE FROM module_products_product_categories WHERE category_id = ?";
+$query = "DELETE FROM ".cms_db_prefix()."module_products_product_categories WHERE category_id = ?";
 $db->Execute($query, array($catid));
 
 $this->RedirectToTab($id);
 
-?>
\ No newline at end of file
+?>
