@@ -56,8 +56,8 @@ if( !$smarty->isCached($this->GetDatabaseResource($thetemplate),$cache_id,$compi
   $rs = $query->execute();
   if( $rs->totalrows == 1 ) {
     $onerow = $rs->get_product_for_display();
-    debug_display($onerow,'after display');
 
+    if( $onerow->hierarchy_id > 0 ) $smarty->assign('active_hierarchy',$onerow->hierarchy_id);
     $smarty->assign('weight_units',product_ops::get_weight_units());  
     $smarty->assign('currency_symbol',product_ops::get_currency_symbol());
     $smarty->assign('entry',$onerow);
