@@ -38,101 +38,83 @@
 #END_LICENSE
 if (!isset($gCms)) exit;
 $this->SetCurrentTab('fielddefs');
+if (!$this->CheckPermission('Modify Products')) return;
 
-if (!$this->CheckPermission('Modify Products'))
-{
-	echo $this->ShowErrors($this->Lang('needpermission', array('Modify Products')));
-	return;
-}
-
-if (isset($params['cancel']))
-{
+if (isset($params['cancel'])) {
   $this->RedirectToTab($id);
 }
 
 $fdid = '';
-if (isset($params['fdid']))
-{
-	$fdid = $params['fdid'];
+if (isset($params['fdid'])) {
+  $fdid = $params['fdid'];
 }
 
 $name = '';
-if (isset($params['name']))
-{
-	$name = $params['name'];
+if (isset($params['name'])) {
+  $name = $params['name'];
 }
 
 $prompt = '';
-if (isset($params['prompt']))
-{
-	$prompt = $params['prompt'];
+if (isset($params['prompt'])) {
+  $prompt = $params['prompt'];
 }
 
 $options = '';
-if (isset($params['options']))
-{
-	$options = $params['options'];
+if (isset($params['options'])) {
+  $options = $params['options'];
 }
 
 $type = '';
-if (isset($params['type']))
-{
-	$type = $params['type'];
+if (isset($params['type'])) {
+  $type = $params['type'];
 }
 
 $max_length = 255;
-if (isset($params['max_length']))
-{
+if (isset($params['max_length'])) {
   $max_length = (int)$params['max_length'];
 }
 
 $origname = '';
-if (isset($params['origname']))
-{
-	$origname = $params['origname'];
+if (isset($params['origname'])) {
+  $origname = $params['origname'];
 }
 
 $public = 0;
-if( isset($params['public']) )
-  {
-    $public = (int)$params['public'];
-  }
+if( isset($params['public']) ) {
+  $public = (int)$params['public'];
+}
 
-if (isset($params['submit']))
-{
-  if( $type == '' )
-    {
-      echo $this->ShowErrors($this->Lang('error_nofieldtype'));
-    }
-  else if ($name == '')
-    {
-      echo $this->ShowErrors($this->Lang('nonamegiven'));
-    }
-  else if( !$this->is_alias($name) )
-    {
-      echo $this->ShowErrors($this->Lang('error_invalid_name'));
-    }
-  else if( !empty($maxlength) && !is_numeric($max_length) )
-    {
-      echo $this->ShowErrors($this->Lang('notanumber'));
-    }
-  else if( $type == 'subscription' && $db->GetOne('SELECT id FROM '.cms_db_prefix().'module_products_fielddefs WHERE type = ?',array($type)) )
-    {
-      echo $this->ShowErrors($this->Lang('error_onesubscriptionfield'));
-    }
-  else if( $type == 'quantity' && $db->GetOne('SELECT id FROM '.cms_db_prefix().'module_products_fielddefs WHERE type = ?',array($type)) )
-    {
-      echo $this->ShowErrors($this->Lang('error_onequantityfield'));
-    }
-  else
-    {
-      $query = 'UPDATE '.cms_db_prefix().'module_products_fielddefs SET name = ?, prompt = ?, type = ?, max_length = ?, modified_date = '.$db->DBTimeStamp(time()).', public = ?, options = ? WHERE id = ?';
-      $res = $db->Execute($query, 
-			  array($name, $prompt, $type, $max_length, $public, $options, $fdid));
+if (isset($params['submit'])) {
+  if( $type == '' ) {
+    echo $this->ShowErrors($this->Lang('error_nofieldtype'));
+  }
+  else if ($name == '') {
+    echo $this->ShowErrors($this->Lang('nonamegiven'));
+  }
+  else if( !$this->is_alias($name) ) {
+    echo $this->ShowErrors($this->Lang('error_invalid_name'));
+  }
+  else if( !empty($maxlength) && !is_numeric($max_length) ) {
+    echo $this->ShowErrors($this->Lang('notanumber'));
+  }
+  else if( $type == 'subscription' && $db->GetOne('SELECT id FROM '.cms_db_prefix().'module_products_fielddefs WHERE type = ?',array($type)) ) {
+    echo $this->ShowErrors($this->Lang('error_onesubscriptionfield'));
+  }
+  else if( $type == 'quantity' && $fdid == '' && 
+	   $db->GetOne('SELECT id FROM '.cms_db_prefix().'module_products_fielddefs WHERE type = ?',array($type)) ) {
+    echo $this->ShowErrors($this->Lang('error_onequantityfield'));
+  }
+  else if( $type == 'quantity' && $fdid != '' && 
+	   $db->GetOne('SELECT id FROM '.cms_db_prefix().'module_products_fielddefs WHERE type = ? AND id != ?',array($type,(int)$fdid)) ) {
+    echo $this->ShowErrors($this->Lang('error_onequantityfield'));
+  }
+  else {
+    $query = 'UPDATE '.cms_db_prefix().'module_products_fielddefs SET name = ?, prompt = ?, type = ?, max_length = ?, modified_date = '.$db->DBTimeStamp(time()).', public = ?, options = ? WHERE id = ?';
+    $res = $db->Execute($query, array($name, $prompt, $type, $max_length, $public, $options, $fdid));
       
-      if( !$res ) die( $db->ErrorMsg() );
-      $this->RedirectToTab($id);
-    }
+    if( !$res ) die( $db->ErrorMsg() );
+    $this->RedirectToTab($id);
+  }
 }
 else
 {
@@ -153,8 +135,7 @@ else
 
 #Display template
 $smarty->assign('options',$options);
-$smarty->assign('startform', 
-		$this->CGCreateFormStart($id, 'editfielddef', $returnid));
+$smarty->assign('startform', $this->CGCreateFormStart($id, 'editfielddef', $returnid));
 $smarty->assign('endform', $this->CreateFormEnd());
 $smarty->assign('inputname', $this->CreateInputText($id, 'name', $name, 20, 255));
 $smarty->assign('inputprompt',$this->CreateInputText($id,'prompt',$prompt,50,255));
