@@ -53,6 +53,7 @@ $lang['confirm_deletealloptions'] = 'Are you sure you want to delete all options
 $lang['confirm_import'] = "Are you sure you really want to do this?\\n\\nImproper settings, or an invalid config file could completely corrupt a currently valid and working system.";
 $lang['copy'] = 'Copy';
 $lang['copy_product'] = 'Copy this item';
+$lang['copy_attribute'] = 'Copy Product Option';
 $lang['copy_attrib_sets'] = 'Copy Attribute Sets';
 $lang['copy_category']  = 'Copy Category';
 $lang['copy_options_from'] = 'Copy all options from';
@@ -91,7 +92,8 @@ $lang['edit_attribsets_for'] = 'Edit Attribute Sets For';
 $lang['edit_attributes'] = 'Edit Attributes';
 $lang['edit_category'] = 'Edit Category';
 $lang['edit_category_fields'] = 'Edit Category Fields for &quot;%s&quot;';
-$lang['edit_hierarochy_item'] = 'Edit Hierarchy Item';
+$lang['edit_hierarchy_item'] = 'Edit Hierarchy Item';
+$lang['edit_notes'] = 'Edit Notes';
 $lang['edit_option_notes'] = 'Edit Option Notes';
 $lang['edit_options'] = 'Edit Product Options';
 $lang['edit_product'] = 'Edit Item ';
@@ -265,7 +267,7 @@ $lang['param_detailpage'] = 'This specifies the pageid or alias that should be u
 $lang['param_detailtemplate'] = 'This parameter specifies the template that should be used for the detail mode display.  If no value is specified, then the current default template of that type is used.  This parameter has no use when pretty urls are enabled.';
 $lang['param_excludecat'] = 'Applicable only to the default (summary) view, this parameter will allow excluding items that are in a specific category from the result. A comma separated list of category names is allowed. This parameter can work in conjunction with the category parameter to provide a list of the items that are in this category, but not in that category';
 $lang['param_field'] = 'Used in the <em>fieldlist</em> and the <em>ajax_propval</em> actions. In the fieldlist action, this parameter is required to specify the name of a user defined property to create a list from.  In the ajax_propval action this parameter is used to specify which field to use to extract a list of values.  Any valid field names are accepted (though only text field and dropdown field names will work properly.  Additionally the special values ::name::, ::sku::, and ::alias:: can be specified to return values from the item name, sku and alias respectively.';
-$lang['param_fieldval'] = 'Used in the <em>default</em> and <em>ajax_propval</em> actions, this parameter allows specifying a field value to limit results by.  In the default value these special values are accepted: &quot;::null::&quot; &quot;::notnull::&quot;. In the ajax_propval action this field is expected to contain only a few letters, to indicate a small filter.  i.e: fieldval=b to return all field values that begin with the letter b.';
+$lang['param_fieldval'] = 'Used in the <em>default</em> and <em>ajax_propval</em> actions, this parameter allows specifying a field value to limit results by.  In the default value these special values are accepted: &quot;::null::&quot; &quot;::notnull::&quot; and wildcard chars (* or %). In the ajax_propval action this field is expected to contain only a few letters, to indicate a small filter.  i.e: fieldval=b to return all field values that begin with the letter b.';
 $lang['param_hierarchy'] = 'Useed in the <em>default</em> and hierachy actions this parameter has two uses.  When used in the default (summary) action, this parameter specifies that only items in that location of the hierarchy should be displayed.  Wildcard character can be used so that you can specify parent/child relationships as well.  i.e {Products hierarchy=\'trucks*\'} will create a summary report of all trucks, including the children in the hierarchy.  Similarly, {Products hierarchy=\'*trucks\'} will display a summary report of all trucks, and all items beloging to any parent in the hierarchy.  A comma separated list of expressions can be supplied.  i.e: {Products action=hierarchy hierarchy=\'trucks,cars\'}';
 $lang['param_hierarchytemplate'] = 'This parameter specifies the template that should be used for the hierarchy display. If no value is specified, then the current default template of that type is used.';
 $lang['param_inline'] = 'Useful only with the search action, this parameter specifies that the output of the summary view should be displayed inline';
@@ -429,10 +431,14 @@ $lang['taxable'] = 'Taxable';
 $lang['test'] = 'Test';
 $lang['textarea'] = 'Text Area';
 $lang['textbox'] = 'Text Input';
+$lang['title_adjustment'] = 'Enter an adjustment from the base price for the product options.  Syntax is [+-]#.##';
+$lang['title_attribute_text'] = 'Enter a brief description for this product option';
 $lang['title_byhierarchy_dflttemplate'] = 'Default New Hierarchy Report Template';
 $lang['title_categorylist_dflttemplate'] = 'Default New CategoryList Template';
 $lang['title_detail_dflttemplate'] = 'Default New Detail Template';
+$lang['title_qoh'] = 'Optionally specify a quantity on hand for this product option.  Note for quantity adjustments to be automatic the SKU field must also be populated';
 $lang['title_search_dflttemplate'] = 'Default New Search Template';
+$lang['title_sku'] = 'The SKU is used for managing quantity on hand, and promotions for product options.';
 $lang['title_summary_dflttemplate'] = 'Default New Summary Template';
 $lang['type'] = 'Type';
 
