@@ -12,6 +12,7 @@ $lang['add_category_field'] = 'Das Feld mit der Kategorie &quot;%s&quot; verkn&u
 $lang['add_hierarchy_item'] = 'Ein Hierarchie-Element hinzuf&uuml;gen';
 $lang['add_option'] = 'Attribut-Option hinzuf&uuml;gen';
 $lang['admin_only'] = 'Sollen nur Administratoren dieses Attribut sehen k&ouml;nnen?';
+$lang['advanced'] = 'Erweitert';
 $lang['align_ul'] = 'Oben Links';
 $lang['align_uc'] = 'Oben Mitte';
 $lang['align_ur'] = 'Open Rechts';
@@ -28,7 +29,9 @@ $lang['areyousure'] = 'Sind Sie sicher?';
 $lang['areyousure_deleteproduct'] = 'Wollen Sie wirklich diesen Artikel und alle damit verkn&uuml;pften Informationen l&ouml;schen?';
 $lang['ascending'] = 'Aufsteigend';
 $lang['attribute_name'] = 'Attributname';
+$lang['attrib_text'] = 'Text';
 $lang['automatic'] = 'Automatisch';
+$lang['btn_setecomhandlers'] = 'Ecommerce Event Handler setzen';
 $lang['byhierarchytemplates'] = 'Hierarchie-Report-Templates';
 $lang['byhierarchytemplate_addedit'] = 'Ein Hierarchie-Report-Template hinzuf&uuml;gen/&auml;ndern';
 $lang['cancel'] = 'Abbrechen';
@@ -39,12 +42,16 @@ $lang['categorylisttemplates'] = 'Kategorielisten-Templates';
 $lang['categorylisttemplate_addedit'] = ' Ein Kategorie-Listentemplate hinzuf&uuml;gen/&auml;ndern';
 $lang['centimeters'] = 'Zentimeter';
 $lang['checkbox'] = 'Kontrollk&auml;stchen';
-$lang['confirm_copyattributes'] = 'Aany existing attribute sets for this product will be removed. Are you sure you want to continue?';
+$lang['confirm_copyoptions'] = 'Any existing options for this item will be replaced. Are you sure you want to continue?';
 $lang['confirm_delete_hierarchy_node'] = 'M&ouml;chten Sie diesen Knoten wirklich l&ouml;schen? Alle Artikel, die diesen Knoten nutzen, werden auf &quot;no hierarchy&quot; gesetzt';
+$lang['confirm_deletealloptions'] = 'Sind Sie sicher, dass Sie alle Optionen f&uuml;r dieses Produkts l&ouml;schen m&ouml;chten?';
 $lang['confirm_import'] = 'Wollen Sie dies WIRKLICH?\n\nFalsche Einstellungen oder eine ung&uuml;ltige Konfigurationsdatei k&ouml;nnen ein bislang funktionierendes System komplett zerst&ouml;ren.';
 $lang['copy'] = 'Kopieren';
+$lang['copy_product'] = 'Diesen Artikel kopieren';
+$lang['copy_attribute'] = 'Copy Product Option';
 $lang['copy_attrib_sets'] = 'Atribut S&auml;tze kopieren';
 $lang['copy_category'] = 'Kategorie kopieren';
+$lang['copy_options_from'] = 'Alle Optionen kopieren von';
 $lang['createddate'] = 'Erstellungsdatum';
 $lang['current_value'] = 'Aktueller Wert';
 $lang['data'] = 'Daten';
@@ -52,6 +59,7 @@ $lang['default'] = 'Standardeinstellung';
 $lang['defaulttemplates'] = 'Standard-Templates';
 $lang['default_template_notice'] = '<strong>Achtung:</strong> Die Inhalte dieser Textfelder werden genutzt, um die voreingestellten Inhalte der Templates festzulegen, wenn &quot;Template hinzuf&uuml;gen&quot; in der jeweiligen Template-Registerkarte geklickt wird. Die Ver&auml;nderung eines Feldes hat keinen direkten Effekt auf die Webseite.';
 $lang['delete'] = 'L&ouml;schen';
+$lang['delete_all'] = 'Alle l&ouml;schen';
 $lang['delete_attribset'] = 'Attribut l&ouml;schen';
 $lang['delete_hierarchy_item'] = 'Hierarchie-Element l&ouml;schen';
 $lang['descending'] = 'Absteigend';
@@ -73,39 +81,61 @@ $lang['edit_attribsets_for'] = 'Attributeinstellungen bearbeiten f&uuml;r';
 $lang['edit_attributes'] = 'Attribute bearbeiten';
 $lang['edit_category'] = 'Kategorie bearbeiten';
 $lang['edit_category_fields'] = 'Kategorienfelder bearbeiten';
-$lang['edit_hierarchy_item'] = 'Hierarchie-Element bearbeiten';
+$lang['edit_hierarochy_item'] = 'Edit Hierarchy Item';
+$lang['edit_notes'] = 'Edit Notes';
+$lang['edit_option_notes'] = 'Edit Option Notes';
+$lang['edit_options'] = 'Produktoptionen bearbeiten';
+$lang['edit_product'] = 'Artikel bearbeiten';
+$lang['errors'] = 'Fehler';
 $lang['error_attribset_exists'] = 'Ein Attribut mit diesem Namen existiert bereits.';
+$lang['error_dberror'] = 'Database error';
 $lang['error_duplicate_sku'] = 'Doppelte Artikelnummer gefunden';
 $lang['error_fieldvalue_empty'] = 'Der Wert des Feldes darf nicht leer sein';
 $lang['error_fileformat'] = 'Problem mit dem Datei-Format';
 $lang['error_filenotfound'] = 'Die Datei wurde nicht gefunden';
 $lang['error_fileopen'] = 'Problem beim &Ouml;ffnen der Datei %s';
+$lang['error_invalidparamcount'] = 'Invalid (or not matching) parameter count';
 $lang['error_invalidparent'] = 'Ung&uuml;ltiges, &uuml;bergeordnetes Element (ein Hierarchieelement kann nicht sein eigenes &uuml;bergeordnetes Element sein)';
 $lang['error_invalid_name'] = 'Der eingegebene Wert im benutzerdefinierten Formular-Feld ist ung&uuml;ltig (beinhaltet nicht-alphanumerischen Zeichen)';
 $lang['error_invalid_value'] = 'Ung&uuml;ltiger Wert angegeben';
 $lang['error_missingparam'] = 'Ein ben&ouml;tigter Parameter fehlt oder ist ung&uuml;ltig';
 $lang['error_nameused'] = 'An Element mit diesem Namen existiert bereits';
+$lang['error_needtworows'] = 'A minimum of two rows is requried';
 $lang['error_nofieldtype'] = 'Bitte w&auml;hlen Sie einen Feldtyp';
 $lang['error_noname'] = 'Sie m&uuml;ssen einen Namen angeben';
+$lang['error_onequantityfield'] = 'Only one quantity field is allowed';
 $lang['error_onesubscriptionfield'] = 'Es kann nur ein Abonnement-Feld angelegt werden';
 $lang['error_permissiondenied'] = 'Berechtigung verweigert';
 $lang['error_product_aliasused'] = 'Der eingegebene Alias wird bereits verwendet';
 $lang['error_product_nameused'] = 'Ein Artikel mit diesem Namen existiert bereits';
 $lang['error_product_notfound'] = 'Das angefragte Produkt konnte nicht gefunden werden';
 $lang['error_product_skuused'] = 'Diese Artikelnummer wird bereits von einem anderen Artikel verwendet';
+$lang['error_product_skuused_atrow'] = 'That SKU value at row %d is already in use by another item';
 $lang['error_price_adjustment'] = 'Ung&uuml;ltige Preis-Angaben f&uuml;r das Element %s';
+$lang['erorr_qoh_negative_atrow'] = 'Quantity on hand cannot be negative at row %d';
 $lang['error_sku_required'] = 'Bitte eine eindeutige Artikelnummer eingeben';
+$lang['error_sku_required_atrow'] = 'Please enter a unique SKU on row %d';
+$lang['error_text_empty_atrow'] = 'The text field at row %d cannot be empty';
 $lang['error_upload_failed'] = 'Das Hochladen ist fehlgeschlagen: %s';
 $lang['exclude_categories'] = 'Produkte aus den gew&auml;hlten Kategorieen nicht im Ergebnis anzeigen';
 $lang['expire_six_months'] = 'Nach sechs Monaten';
 $lang['expire_one_year'] = 'Nach einem Jahr';
 $lang['expire_two_year'] = 'Nach zwei Jahren';
+$lang['export_to_csv'] = 'Als CSV exportieren';
+$lang['exportattribs'] = 'Attribute exportieren';
+$lang['exportcats'] = 'Kategorien exportieren';
+$lang['exportdelim'] = 'Export field Delimiter';
+$lang['exportdraft'] = 'Artikel im Entwurf exportieren';
+$lang['exportfields'] = 'Export Custom Fields';
 $lang['extra1'] = 'Extrafeld 1';
 $lang['extra2'] = 'Extrafeld 2';
 $lang['field'] = 'Feld';
+$lang['fields'] = 'Felder';
 $lang['fielddef'] = 'Felddefinition';
 $lang['fielddefs'] = 'Felddefinitionen';
 $lang['file'] = 'Datei';
+$lang['filter'] = 'Filter';
+$lang['filterinuse'] = 'in effect';
 $lang['filters'] = 'Filter';
 $lang['firstpage'] = '<<';
 $lang['general_settings'] = 'Allgemeine Einstellungen';
@@ -126,6 +156,9 @@ $lang['info_autowatermark'] = 'Es werden die Wasserzeichen-Einstellungen des CGE
 $lang['info_batchsize'] = 'Geben Sie die Anzahl der Zeilen an, die pro &quot;Block&quot; verarbeitet werden sollen. Nachdem ein Block abgearbeitet ist, wird der Import weitergeleitet und verarbeitet den n&auml;chsten Block.  Wenn bei Ihnen Speicherfehler oder Zeit&uuml;berschreitungen aufgrund der Gr&ouml;&szlig;e der verarbeiteten Datenmenge auftreten, wenden Sie sich an Ihren Hosting-Provider oder verkleinern Sie die Zeilenanzahl';
 $lang['info_cart_module_params'] = 'Diese Parameter werden verwendet, um ein Warenkorb-Modul f&uuml;r die Artikel-Detail- und -Listenansicht auszuw&auml;hlen.';
 $lang['info_copy_attribsets'] = 'Hiermit kopieren Sie den Attributsatz (ohne Artikelnummer) eines anderen Artikels.';
+$lang['info_clearattribs'] = 'Only applicable when updating existing items, this will clear all attribute information from the database for items before creating new ones';
+$lang['info_clearcategories'] = 'Only applicable when updating existing items, this will clear all category memberships befoe creating new ones';
+$lang['info_clearfields'] = 'Only applicable when updating existing items, this will clear all fields befoe creating field values';
 $lang['info_createfields'] = 'Unbekannte Artikelfelder automatisch erstellen? <em>(werden als Textfelder erstellt)</em>';
 $lang['info_createcategories'] = 'In der CSV-Datei angegebene, aber bisher fehlende Artikelkategorien automatisch erzeugen';
 $lang['info_createhierarchy'] = 'In der CSV-Datei angegebene, aber bisher fehlende Artikelhierarchien automatisch erzeugen';
@@ -137,14 +170,18 @@ $lang['info_fieldproblems'] = 'Bei einem oder mehreren benutzerdefinierten Felde
 $lang['info_handleimages'] = 'Sollen beim Import in einer Spalte gefundene Bilddateien von der Quellposition verschoben, mit Wasserzeichen versehen und ein Vorschaubild erstellt und der Feldtyp auf &quot;Bild&quot; gesetzt werden';
 $lang['info_hierpage'] = 'Diese Seite f&uuml;r Hierarchieansichten verwenden.  Die Seiten-ID wird in der URL nicht verwendet.';
 $lang['info_imagepath'] = 'Ein Pfad (relativ zum Uploads Verzeichnis) in dem die in der Importdatei angegebenen Bilder liegen';
+$lang['info_imagestuff_deprecated'] = 'Image processing functions are deprecated and will be removed in a future version.  Use CGSmartImage for inline image processing.';
 $lang['info_import_test_passed'] = 'Die angegebene Eingabedatei wurde einem Kurztest unterzogen und alles scheint in Ordnung zu sein.<br/>Dies ist kein Indiz daf&uuml;r, das die Datei fehlerfrei ist.';
 $lang['info_prettyhierurls'] = 'Den Hierarchienamen in die URL einf&uuml;gen';
 $lang['info_price_adjustment'] = 'G&uuml;ltige Eingaben sind +-*#.##';
 $lang['info_prodnotfound'] = 'Wie wird ein direkter Aufruf einer Artikeldetailseite per URL behandelt, wenn der Artikel - aus welchen Gr&uuml;nden auch immer (deaktiviert, gel&ouml;scht, usw) - nicht verf&uuml;gbar ist.';
 $lang['info_publicfield'] = '&Ouml;ffentliche Felder sind auf der Webseite f&uuml;r jeden sichtbar.';
+$lang['info_reorder_content'] = 'This operation allows dragging the individual nodes in the tree to adjust the order that they will be displayed in in the hierarchy view';
+$lang['info_setecomhandlers'] = 'This button will ensure that event handlers for ecommerce events are in place.  This is useful if asking the items module to keep track of a quantity on hand, but the event handlers did not get created during install or upgrade';
 $lang['label'] = 'Beschriftung';
 $lang['label_skip'] = '&Uuml;berspringen';
 $lang['label_overwrite'] = '&Uuml;berschreiben';
+$lang['label_update'] = 'Aktualisieren';
 $lang['lastpage'] = '>>';
 $lang['last_modified'] = 'Letzte &Auml;nderung';
 $lang['logotext'] = 'Zweites Bild';
@@ -153,6 +190,11 @@ $lang['modifieddate'] = '&Auml;nderungs-Datum';
 $lang['module_description'] = 'Ein Modul, um einen Katalog von Artikeln, deren Preise, Bilder, etc. zu verwalten und Benutzern zu erlauben, diese an einen Warenkorb zu &uuml;bergeben.';
 $lang['move_down'] = 'Nach unten';
 $lang['move_up'] = 'Nach oben';
+$lang['msg_eventhandlers_created'] = 'Event handlers created';
+$lang['msg_optionscopied'] = 'Product options copied (but not saved yet)';
+$lang['msg_options_deleted'] = 'Product options deleted for product %d';
+$lang['msg_options_saved'] = 'Product options saved';
+$lang['msg_productcopied'] = 'Item successfully copied.  You are now editing the copy.  Any sku information in the item, and/or attributes has been cleared';
 $lang['name'] = 'Name ';
 $lang['needpermission'] = 'Sie haben nicht die erforderliche Berechtigung: %s';
 $lang['new_category_name'] = 'Neuer Kategorien-Name';
@@ -160,8 +202,11 @@ $lang['nextpage'] = '>';
 $lang['no'] = 'Nein';
 $lang['nonamegiven'] = 'Es wurde kein Name angegeben';
 $lang['none'] = 'Keines';
+$lang['notes'] = 'Notes';
 $lang['nothing_selectd'] = 'Nichts ausgew&auml;hlt';
 $lang['of'] = 'Von';
+$lang['ok'] = 'OK';
+$lang['operation_cancelled'] = 'Vorgang abgebrochen';
 $lang['operation_complete'] = 'Vorgang abgeschlossen';
 $lang['page'] = 'Seite';
 $lang['page_of'] = 'Seite %s von %s';
@@ -185,8 +230,10 @@ $lang['param_fieldval'] = 'Used only in the <em>default</em> action, this parame
 $lang['param_hierarchy'] = 'Dieser Parameter ist nur in der <em>default</em>-Ansicht sinnvoll. Er wird verwendet, um nur Artikel anzuzeigen, die einer bestimmten Hierarchie angeh&ouml;ren. Dabei k&ouml;nnen Wildcards verwendet werden, um &uuml;bergeordnete/untergeordnete Beziehungen ebenfalls anzuzeigen. Z.B. gibt {Products hierarchy=&#039;LKWs*&#039;} eine Zusammenfassung aller LKWs aus, einschlie&szlig;lich aller untergeordneten Elemente der Hierarchie. Genauso gibt {Products hierarchy=&#039;*LKWs&#039;} eine Zusammenfassung aller LKWs aus, einschlie&szlig;lich der &uuml;bergeordneten Elemente in der Hierarchie.';
 $lang['param_hierarchytemplate'] = 'Dieser Parameter wird verwendet, um das Template festzulegen, welches f&uuml;r die Hierarchieansicht verwendet werden soll. Ohne Vorgabe wird das Standard-Template verwendet.';
 $lang['param_inline'] = 'Useful only with the search action, this parameter specifies that the output of the summary view should be displayed inline';
+$lang['param_notpretty'] = 'This parameter specifies a comma separated list of actions to which pretty urls should not be generated.  i.e: notpretty=hierarchy,default will not generate pretty urls to hierarchy, or summary (default) actions, but will allow generation of pretty urls to detail views.  As a special value &quot;all&quot; can be used to specify that no pretty urls should be generated';
 $lang['param_pagelimit'] = 'Dieser Parameter ist nur in der <em>default</em>-Ausgabe sinnvoll. Er legt fest, wie viele Elemente pro Seite angezeigt werden sollen.';
 $lang['param_parent'] = 'Dieser Parameter ist nur in der <em>hierarchy</em>-Ausgabe sinnvoll. Er legt die Hierarchie-ID fest, ab welcher die Artikel ausgegeben werden sollen.';
+$lang['param_parents'] = 'Useful only in the <em>hierarchy</em> action, this parameter specifies a comma separated list of hierarchy names that specify to create numerous heirarchy trees from the specified location(s).  Hierarchy names must be unique, and not contain any special chars.';
 $lang['param_productid'] = 'Dieser Parameter ist nur in der <em>detail</em> Artikelansicht sinnvoll. Er legt fest, welcher Artikel angezeigt werden soll.';
 $lang['param_productlist'] = 'Applicable only to the default (summary) view, this parameter allows specifying a comma separated list of integer product ids to display.  No pagination or sorting is performed on these values, and if specified the other filtering parameters to the summary view are ignored.';
 $lang['param_resultpage'] = 'Applicable only to the search, and category list actions, this parameter specifies a page id or alias to use to display the summary results';
@@ -219,6 +266,7 @@ $lang['preferences'] = 'Einstellungen';
 $lang['preuninstall'] = 'Wenn Sie dieses Modul entfernen, werden auch alle zugeh&ouml;rigen Daten gel&ouml;scht. Wollen Sie das wirklich?';
 $lang['price'] = 'Preis';
 $lang['price_adjustment'] = 'Preis-Einstellung';
+$lang['prefix_copyof'] = 'Kopie von';
 $lang['prevpage'] = '<';
 $lang['product'] = 'Artikel';
 $lang['productname'] = 'Artikel-Name';
@@ -227,6 +275,7 @@ $lang['product_detail_settings'] = 'Artikeldetail-Einstellungen';
 $lang['product_editing_settings'] = 'Produkt Bearbeitungsoptionen ';
 $lang['product_summary_settings'] = 'Produkt&uuml;bersicht Einstellungen';
 $lang['product_hierarchy'] = 'Artikel-Hierarchie';
+$lang['product_info'] = 'Artikel-Information';
 $lang['product_manager'] = 'Artikelverwaltung';
 $lang['progress'] = 'Fortschritt';
 $lang['prompt'] = 'Eingabe';
@@ -243,6 +292,9 @@ $lang['prompt_applicable'] = 'Aktivierung per Voreinstellung f&uuml;r alle neuen
 $lang['prompt_batchsize'] = 'Blockgr&ouml;&szlig;e';
 $lang['prompt_cart_module'] = 'Cart-Modul';
 $lang['prompt_cart_module_params'] = 'Cart-Modul Parameter';
+$lang['prompt_clearattribs'] = 'Clear attributes on update';
+$lang['prompt_clearcategories'] = 'Clear categories on update';
+$lang['prompt_clearfields'] = 'Clear fields on update';
 $lang['prompt_createcategories'] = 'Kategorien erstellen';
 $lang['prompt_createfields'] = 'Artikelfelder erstellen?';
 $lang['prompt_createhierarchy'] = 'Eine Artikel-Hierarchie erstellen';
@@ -271,6 +323,7 @@ $lang['prompt_prettyhierurls'] = 'Suchmaschinenfreundliche URLs (Pretty URLS) f&
 $lang['prompt_prod_detailpage'] = 'Standardseite f&uuml;r Produkt Detailansicht';
 $lang['prompt_products_matching'] = 'Produkte passend %s';
 $lang['prompt_sku_required'] = 'Art.-Nr ist ein Pflichtfeld (muss bei allen Artikeln angegeben werden)';
+$lang['prompt_summary_newdefault'] = 'Neue Listenansicht verwenden';
 $lang['prompt_summarypagelimit'] = 'Voreingestelltes Produktlimit in der Listenansicht';
 $lang['prompt_summarysortorder'] = 'Voreingestellte Sortier-Reihenfolge in der Listenansicht';
 $lang['prompt_summarysorting'] = 'Voreingestelltes Sortier-Feld in der Listenansicht';
@@ -282,7 +335,10 @@ $lang['prompt_usehierpathurls'] = 'Die Hierarchienamen in die URL von Artikeldet
 $lang['prompt_weightunits'] = 'Gewichts-Einheit';
 $lang['public'] = 'Ist dies ein &ouml;ffentliches Feld?';
 $lang['published'] = 'Ver&ouml;ffentlicht';
+$lang['quantity_on_hand'] = 'Verf&uuml;gbare Menge';
 $lang['random'] = 'Zuf&auml;llig';
+$lang['reorder_hierarchy'] = 'Reorder Hierarchy';
+$lang['reset'] = 'Zur&uuml;cksetzen';
 $lang['resettofactory'] = 'Auf die programmseitigen Voreinstellungen zur&uuml;cksetzen';
 $lang['return'] = 'Zur&uuml;ck';
 $lang['return_to_top'] = 'Zur&uuml;ck nach oben';
@@ -320,10 +376,14 @@ $lang['taxable'] = 'MwSt.';
 $lang['test'] = 'Test ';
 $lang['textarea'] = 'Mehrzeiliges Textfeld';
 $lang['textbox'] = 'Einzeiliges Textfeld';
+$lang['title_adjustment'] = 'Enter an adjustment from the base price for the product options.  Syntax is [+-]#.##';
+$lang['title_attribute_text'] = 'Enter a brief description for this product option';
 $lang['title_byhierarchy_dflttemplate'] = 'Voreinstellung Neues Hierarchie Ausgabe Template';
 $lang['title_categorylist_dflttemplate'] = 'Voreinstellung Neues Kategorie-Ausgabe Template';
 $lang['title_detail_dflttemplate'] = 'Voreinstellung Neues Artikel-Detailansicht Template';
+$lang['title_qoh'] = 'Optionally specify a quantity on hand for this product option.  Note for quantity adjustments to be automatic the SKU field must also be populated';
 $lang['title_search_dflttemplate'] = 'Voreinstellung Neues Suchformular Template';
+$lang['title_sku'] = 'The SKU is used for managing quantity on hand, and promotions for product options.';
 $lang['title_summary_dflttemplate'] = 'Voreinstellung Neues Artikel-Listenansicht Template';
 $lang['type'] = 'Typ';
 $lang['up'] = 'Nach oben';
@@ -335,12 +395,13 @@ $lang['value'] = 'Wert';
 $lang['values'] = 'Werte';
 $lang['view'] = 'Anzeigen';
 $lang['viewable_fields'] = 'W&auml;hlen Sie benutzerdefinierte Felder in der Tabellenansicht';
+$lang['warn_edit_product_options'] = 'Each product option must have a unique string.  If SKU is required then it must be unique across the entire system.';
 $lang['watermark_location'] = 'Platzierung des Wasserzeichens';
 $lang['weight'] = 'Gewicht';
 $lang['with_selected'] = 'Ausgew&auml;hlte Eintr&auml;ge';
 $lang['yes'] = 'Ja';
-$lang['qca'] = 'P0-1362779760-1309265682636';
-$lang['utma'] = '156861353.1681295217.1311961821.1312317698.1312377783.16';
-$lang['utmz'] = '156861353.1311961821.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
+$lang['utmb'] = '156861353';
+$lang['utma'] = '156861353.2042345210.1376300813.1376497742.1376671575.3';
 $lang['utmc'] = '156861353';
-?>
+$lang['utmz'] = '156861353.1376300813.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
+?>
\ No newline at end of file
