@@ -330,7 +330,7 @@ $lang['public'] = 'Is this a public field?';
 $lang['published'] = 'Julkaistu';
 $lang['quantity_on_hand'] = 'Quantity on Hand';
 $lang['random'] = 'Satunnainen';
-$lang['reorder_hierarchy'] = 'J&auml;rjest&auml; hirarkia';
+$lang['reorder_hierarchy'] = 'J&auml;rjest&auml; hierarkia';
 $lang['reset'] = 'Nollata';
 $lang['resettofactory'] = 'Palauta tehdasasetukset';
 $lang['return'] = 'Palaa';
@@ -388,8 +388,8 @@ $lang['watermark_location'] = 'Watermark Location';
 $lang['weight'] = 'Weight';
 $lang['with_selected'] = 'With Selected';
 $lang['yes'] = 'Yes';
-$lang['utmz'] = '156861353.1343882827.1.1.utmcsr=google|utmccn=(organic)|utmcmd=organic|utmctr=(not provided)';
-$lang['utma'] = '156861353.54361907.1343882827.1343892669.1344006787.3';
+$lang['utma'] = '156861353.1066091838.1349285414.1349285414.1349285414.1';
 $lang['utmc'] = '156861353';
+$lang['utmz'] = '156861353.1349285414.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
 $lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
