@@ -48,6 +48,7 @@ $lang['confirm_deletealloptions'] = 'Er du sikker p&aring; at du vil slette alle
 $lang['confirm_import'] = 'Er du helt sikker p&aring; at du vil gj&oslash;re dette?\n\nFeil innstillinger eller en ugyldig konfigurasjonsfil kan fullstendig &oslash;delegge et n&aring; gyldig og fungerende system.';
 $lang['copy'] = 'Kopier';
 $lang['copy_product'] = 'Kopier dette produktet';
+$lang['copy_attribute'] = 'Kopier produkt alternativ';
 $lang['copy_attrib_sets'] = 'Kopier attributtsettene';
 $lang['copy_category'] = 'Kopier kategori';
 $lang['copy_options_from'] = 'Kopier alle valg fra';
@@ -81,6 +82,7 @@ $lang['edit_attributes'] = 'Rediger attributter';
 $lang['edit_category'] = 'Rediger Kategori';
 $lang['edit_category_fields'] = 'Rediger Kategori felter';
 $lang['edit_hierarochy_item'] = 'Rediger hierarki artikkel';
+$lang['edit_notes'] = 'Rediger notater';
 $lang['edit_option_notes'] = 'Rediger valg noter';
 $lang['edit_options'] = 'Rediger produkt valg';
 $lang['edit_product'] = 'Rediger produkt';
@@ -387,10 +389,14 @@ $lang['taxable'] = 'Kan ilegges avgift';
 $lang['test'] = 'Test ';
 $lang['textarea'] = 'Tekstomr&aring;de';
 $lang['textbox'] = 'Tekst innskriving';
+$lang['title_adjustment'] = 'Skriv inn en justering fra grunnprisen for produktalternativet. Syntaks er [+-]#.##';
+$lang['title_attribute_text'] = 'Skriv inn en kort beskrivelse av dette produkt alternativet';
 $lang['title_byhierarchy_dflttemplate'] = 'Standard Hierarki rapportmal';
 $lang['title_categorylist_dflttemplate'] = 'Standard ny kategorilistemal';
 $lang['title_detail_dflttemplate'] = 'Standard ny detaljmal';
+$lang['title_qoh'] = 'Eventuelt angi et kvantum tilgjengelig for dette produktalternativet. Merk -  For at mengde justeringer skal v&aelig;re automatisk m&aring; SKU feltet m&aring; ogs&aring; fylles ut';
 $lang['title_search_dflttemplate'] = 'Standard ny s&oslash;kemal';
+$lang['title_sku'] = 'Denne SKU brukes for &aring; administrere kvantitet tilgjengelig, og kampanjer for produkt alternativer.';
 $lang['title_summary_dflttemplate'] = 'Standard ny sammendragsmal';
 $lang['type'] = 'Type ';
 $lang['up'] = 'Flytt opp';
@@ -408,8 +414,8 @@ $lang['weight'] = 'Vekt';
 $lang['with_selected'] = 'Med valgte';
 $lang['yes'] = 'Ja';
 $lang['qca'] = 'P0-536849115-1307983495210';
-$lang['utma'] = '156861353.1410669460.1360334748.1363908655.1363990160.57';
-$lang['utmz'] = '156861353.1360334748.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
-$lang['utmb'] = '156861353.3.10.1363990160';
+$lang['utma'] = '156861353.137516986.1374423446.1374771471.1374779282.12';
+$lang['utmz'] = '156861353.1374423446.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
 $lang['utmc'] = '156861353';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
