@@ -44,10 +44,11 @@ $lang['centimeters'] = 'Centimeter';
 $lang['checkbox'] = 'Vinkvakje';
 $lang['confirm_copyoptions'] = 'Any existing options for this item will be replaced. Are you sure you want to continue?';
 $lang['confirm_delete_hierarchy_node'] = 'Bent u zeker dat u deze node wilt verwijderen?  Elk product wat gebruik maakt van deze node zal niet meer onder een hi&euml;rarchie vallen.';
-$lang['confirm_deletealloptions'] = 'Are you sure you want to delete all options for this product?';
+$lang['confirm_deletealloptions'] = 'Weet u zeker dat u alle opties voor dit product wilt verwijderen?';
 $lang['confirm_import'] = 'Bent u zeker dat u dit wilt uitvoeren?\n\nVerkeerde instellingen of een verkeerd configuratiebestand kan het hele systeem in de war brengen. Wat resulteert in een niet werkende producten module.';
 $lang['copy'] = 'Kopie';
 $lang['copy_product'] = 'Kopieer dit item';
+$lang['copy_attribute'] = 'Kopieer Product Opties';
 $lang['copy_attrib_sets'] = 'Kopieer attributenset';
 $lang['copy_category'] = 'Categorie kopieren';
 $lang['copy_options_from'] = 'Kopieer alle opties van';
@@ -80,9 +81,10 @@ $lang['edit_attribsets_for'] = 'Attribuut Groep aanpasen voor';
 $lang['edit_attributes'] = 'Attribuut aanpassen';
 $lang['edit_category'] = 'Categorie aanpassen';
 $lang['edit_category_fields'] = 'Categorie Velden aanpassen';
-$lang['edit_hierarochy_item'] = 'Edit Hierarchy Item';
-$lang['edit_option_notes'] = 'Edit Option Notes';
-$lang['edit_options'] = 'Edit Product Options';
+$lang['edit_hierarochy_item'] = 'Wijzig Hierarchy Item';
+$lang['edit_notes'] = 'Wijzig Opmerkingen';
+$lang['edit_option_notes'] = 'Wijzig Optie Opmerkingen';
+$lang['edit_options'] = 'Wijzig Product Opties';
 $lang['edit_product'] = 'Wijzig Item ';
 $lang['errors'] = 'Fouten';
 $lang['error_attribset_exists'] = 'Er bestaat al een attribuut met deze naam';
@@ -98,7 +100,7 @@ $lang['error_invalid_name'] = 'De aangepaste veld waarde die u heeft ingevoerd k
 $lang['error_invalid_value'] = 'Ongeldige waarde opgegeven';
 $lang['error_missingparam'] = 'Een benodigde parameter mist of is niet geldig';
 $lang['error_nameused'] = 'Een item met deze naam is al in gebruik';
-$lang['error_needtworows'] = 'A minimum of two rows is requried';
+$lang['error_needtworows'] = 'Minimaal twee regels is verplicht';
 $lang['error_nofieldtype'] = 'Selecteer a.u.b. een veldtype';
 $lang['error_noname'] = 'U moet een naam invoeren';
 $lang['error_onequantityfield'] = 'Er is slechts een veld met de hoeveelheid toegestaan';
@@ -209,8 +211,7 @@ $lang['operation_complete'] = 'Operatie uitgevoerd';
 $lang['page'] = 'Pagina';
 $lang['page_of'] = 'Pagina %s van %s';
 $lang['page_limit'] = 'Pagina Limiet';
-$lang['param_action'] = '
-Specify the behaviour of the module.  Possible values are:
+$lang['param_action'] = 'Specify the behaviour of the module.  Possible values are:
 <ul>
   <li>hierarchy -- Display an item list by hierarchy</li>
   <li>categorylist - Display a list of item categories</li>
@@ -224,22 +225,16 @@ Specify the behaviour of the module.  Possible values are:
   <li>search - Display a form to allow searching items on various criterium</li>
 <li>ajax_propval - Return a json encoded list of property values matching the criteria specified.  This action is intended to be used via ajax, and should be called with the showtemplate=false parameter on the URL.</li>
 </ul> ';
-$lang['param_category'] = '
-When used in the <em>default</em> summary mode, this parameter, which should match the name of an existing category will be used to display only those items that are in that categoory. (a comma seperated list can be supplied).  This parameter can also be used with the categorylist action to limit the output to the specified item categories. ';
+$lang['param_category'] = 'When used in the <em>default</em> summary mode, this parameter, which should match the name of an existing category will be used to display only those items that are in that categoory. (a comma seperated list can be supplied).  This parameter can also be used with the categorylist action to limit the output to the specified item categories. ';
 $lang['param_categoryfield'] = 'Alleen van toepassing op de &quot;categorylist&quot; actie, deze parameter kan gebruikt worden om categori&euml;n te filteren op basis van de waarde van het categorieveld. Het werkt niet in combinatie met de &quot;category&quot; of de &quot;category_id&quot; parameters. De syntax van deze parameter is een kommagescheiden lijst met veldnamen en veldwaarden.  Bijvoorbeeld:  categorylist=&quot;veldnaam:waarde,veldnaam 2:waarde 2&quot;';
 $lang['param_categorylisttemplate'] = 'Useful only with the categorylist action, this parameter indicates the template that should be used for the display.  If no value is specified then the current default template of that type is used.';
 $lang['param_categorylistdtltemplate'] = 'Useful only with the categorylist actions, this parameter indicates the template that should be used for the display of the category details.  This uses a category list template..  If no value is specified then the current default template of that type is used. ';
-$lang['param_detailpage'] = '
-This specifies the pageid or alias that should be used to display the detail report.  It can be used with the <em>default</em> or search actions.  This option is not compatible with pretty urls of any sort. ';
-$lang['param_detailtemplate'] = '
-This parameter specifies the template that should be used for the detail mode display.  If no value is specified, then the current default template of that type is used.  This parameter has no use when pretty urls are enabled. ';
+$lang['param_detailpage'] = 'This specifies the pageid or alias that should be used to display the detail report.  It can be used with the <em>default</em> or search actions.  This option is not compatible with pretty urls of any sort. ';
+$lang['param_detailtemplate'] = 'This parameter specifies the template that should be used for the detail mode display.  If no value is specified, then the current default template of that type is used.  This parameter has no use when pretty urls are enabled. ';
 $lang['param_excludecat'] = 'Applicable only to the default (summary) view, this parameter will allow excluding products that are in a specific category from the result. A comma separated list of category names is allowed. This parameter can work in conjunction with the category parameter to provide a list of the products that are in this category, but not in that category ';
-$lang['param_field'] = '
-Used in the <em>fieldlist</em> and the <em>ajax_propval</em> actions. In the fieldlist action, this parameter is required to specify the name of a user defined property to create a list from.  In the ajax_propval action this parameter is used to specify which field to use to extract a list of values.  Any valid field names are accepted (though only text field and dropdown field names will work properly.  Additionally the special values ::name::, ::sku::, and ::alias:: can be specified to return values from the item name, sku and alias respectively. ';
-$lang['param_fieldval'] = '
-Used in the <em>default</em> and <em>ajax_propval</em> actions, this parameter allows specifying a field value to limit results by.  In the default value these special values are accepted: &amp;quot;::null::&amp;quot; &amp;quot;::notnull::&amp;quot;. In the ajax_propval action this field is expected to contain only a few letters, to indicate a small filter.  i.e: fieldval=b to return all field values that begin with the letter b. ';
-$lang['param_hierarchy'] = '
-Useed in the <em>default</em> and hierachy actions this parameter has two uses.  When used in the default (summary) action, this parameter specifies that only items in that location of the hierarchy should be displayed.  Wildcard character can be used so that you can specify parent/child relationships as well.  i.e {Products hierarchy=&#039;trucks*&#039;} will create a summary report of all trucks, including the children in the hierarchy.  Similarly, {Products hierarchy=&#039;*trucks&#039;} will display a summary report of all trucks, and all items beloging to any parent in the hierarchy.  A comma separated list of expressions can be supplied.  i.e: {Products action=hierarchy hierarchy=&#039;trucks,cars&#039;} ';
+$lang['param_field'] = 'Used in the <em>fieldlist</em> and the <em>ajax_propval</em> actions. In the fieldlist action, this parameter is required to specify the name of a user defined property to create a list from.  In the ajax_propval action this parameter is used to specify which field to use to extract a list of values.  Any valid field names are accepted (though only text field and dropdown field names will work properly.  Additionally the special values ::name::, ::sku::, and ::alias:: can be specified to return values from the item name, sku and alias respectively. ';
+$lang['param_fieldval'] = 'Used in the <em>default</em> and <em>ajax_propval</em> actions, this parameter allows specifying a field value to limit results by.  In the default value these special values are accepted: &amp;quot;::null::&amp;quot; &amp;quot;::notnull::&amp;quot;. In the ajax_propval action this field is expected to contain only a few letters, to indicate a small filter.  i.e: fieldval=b to return all field values that begin with the letter b. ';
+$lang['param_hierarchy'] = 'Useed in the <em>default</em> and hierachy actions this parameter has two uses.  When used in the default (summary) action, this parameter specifies that only items in that location of the hierarchy should be displayed.  Wildcard character can be used so that you can specify parent/child relationships as well.  i.e {Products hierarchy=&#039;trucks*&#039;} will create a summary report of all trucks, including the children in the hierarchy.  Similarly, {Products hierarchy=&#039;*trucks&#039;} will display a summary report of all trucks, and all items beloging to any parent in the hierarchy.  A comma separated list of expressions can be supplied.  i.e: {Products action=hierarchy hierarchy=&#039;trucks,cars&#039;} ';
 $lang['param_hierarchytemplate'] = 'This parameter specifies the template that should be used for the hierarchy display. If no value is specified, then the current default template of that type is used. ';
 $lang['param_inline'] = 'Useful only with the search action, this parameter specifies that the output of the summary view should be displayed inline ';
 $lang['param_notpretty'] = 'Thie parameter specifies a comma separated list of actions to which pretty urls should not be generated.  i.e: notpretty=hierarchy,default will not generate pretty urls to hierarchy, or summary (default) actions, but will allow generation of pretty urls to detail views.  As a special vaue &quot;all&quot; can be used to specify that no pretty urls should be generated';
@@ -257,8 +252,7 @@ $lang['param_sortorder'] = 'Specify the order of sorted fields in summary view.
   <li><strong>asc</strong> -- Ascending order</li>
   <li>desc -- Descending order</li>
 </ul>';
-$lang['param_sortby'] = '
-Applicable in the summary, categorylist or search actions, this parameter determines the sorting of the output.  Possible values are:
+$lang['param_sortby'] = 'Applicable in the summary, categorylist or search actions, this parameter determines the sorting of the output.  Possible values are:
 <ul>
   <li><strong>item_name</strong></li>
   <li>id -- The item id</li>
@@ -395,10 +389,14 @@ $lang['taxable'] = 'Belastbaar';
 $lang['test'] = 'Testen';
 $lang['textarea'] = 'Tekstruimte';
 $lang['textbox'] = 'Tekst Invoer';
+$lang['title_adjustment'] = 'Enter an adjustment from the base price for the product options.  Syntax is [+-]#.##';
+$lang['title_attribute_text'] = 'Enter a brief description for this product option';
 $lang['title_byhierarchy_dflttemplate'] = 'Standaard nieuw Hierachie Rapport Sjabloon';
 $lang['title_categorylist_dflttemplate'] = 'Standaard nieuw Categorielijst Sjabloon';
 $lang['title_detail_dflttemplate'] = 'Standaard nieuw Detail Sjabloon';
+$lang['title_qoh'] = 'Optionally specify a quantity on hand for this product option.  Note for quantity adjustments to be automatic the SKU field must also be populated';
 $lang['title_search_dflttemplate'] = 'Standaard nieuw Zoek Sjabloon';
+$lang['title_sku'] = 'The SKU is used for managing quantity on hand, and promotions for product options.';
 $lang['title_summary_dflttemplate'] = 'Standaard nieuwe Samenvatting Sjabloon';
 $lang['type'] = 'Type ';
 $lang['up'] = 'Omhoog';
@@ -415,8 +413,8 @@ $lang['watermark_location'] = 'Plaats Watermerk';
 $lang['weight'] = 'Gewicht';
 $lang['with_selected'] = 'Met geselecteerden';
 $lang['yes'] = 'Ja';
-$lang['utma'] = '156861353.679304078.1356693526.1356795711.1356811621.4';
-$lang['utmz'] = '156861353.1356693526.1.1.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/project/files/6';
-$lang['utmc'] = '156861353';
+$lang['utma'] = '156861353.1652442735.1375624076.1375624076.1375624076.1';
+$lang['utmz'] = '156861353.1375624076.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
 $lang['utmb'] = '156861353';
+$lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
