@@ -44,6 +44,8 @@ final class product_ops
   static private $_prodhier;
   static private $_product_cache;
 
+  private function __construct() {}
+
   static public function set_product($product)
   {
     if( !isset($product['id']) || !isset($product['name']) ) {
@@ -61,9 +63,9 @@ final class product_ops
     $query = new products_query();
     $query['product_id'] = (int)$product_id;
     if( $anystatus ) $query['status'] = '*';
-    $results = new products_resultset($query);
-    if( $results->RecordCount() > 1 ) {
-      throw new Exception('INTERNAL ERROR: More than one product with the id '.$product_id);
+    $results = $query->execute();
+    if( $results->totalrows > 1 ) {
+	throw new Exception('INTERNAL ERROR: More than one product with the id '.$product_id);
     }
 
     $product = $results->get_product(FALSE,TRUE);
@@ -75,8 +77,7 @@ final class product_ops
   static public function is_valid_category($name)
   {
     $db = cmsms()->GetDb();
-    $query = 'SELECT id FROM '.cms_db_prefix().'module_products_categories
-               WHERE name = ?';
+    $query = 'SELECT id FROM '.cms_db_prefix().'module_products_categories WHERE name = ?';
     $tmp = $db->GetOne($query,array($name));
     if( $tmp ) return TRUE;
     return FALSE;
@@ -86,8 +87,7 @@ final class product_ops
   public static function is_valid_product_id($pid)
   {
     $db = cmsms()->GetDb();
-    $query = 'SELECT id FROM '.cms_db_prefix().'module_products 
-               WHERE id = ?';
+    $query = 'SELECT id FROM '.cms_db_prefix().'module_products WHERE id = ?';
     $tmp = $db->Execute($query,array($pid));
     if( $tmp ) return TRUE;
     return FALSE;
@@ -330,9 +330,7 @@ final class product_ops
 
     $result = array();
     for( $i = 0; $i < count($tmp); $i++ ) {
-      if( $type == '' || $tmp[$i]['type'] == $type ) {
-	$result[$tmp[$i]['id']] = $tmp[$i]['prompt'];
-      }
+      if( $type == '' || $tmp[$i]['type'] == $type ) $result[$tmp[$i]['id']] = $tmp[$i]['prompt'];
     }
     return $result;
   }
@@ -350,4 +348,4 @@ final class product_ops
 #
 # EOF
 #
-?>
\ No newline at end of file
+?>
