@@ -47,10 +47,7 @@ final class product_utils
   {
     $mod = cge_utils::get_module('Products');
     $items = array();
-    if( $selectone )
-      {
-	$items[$mod->Lang('select_one')] = '';
-      }
+    if( $selectone ) $items[$mod->Lang('select_one')] = '';
     $items[$mod->Lang('textbox')] = 'textbox';
     $items[$mod->Lang('checkbox')] = 'checkbox';
     $items[$mod->Lang('textarea')] = 'textarea';
@@ -60,6 +57,10 @@ final class product_utils
     $items[$mod->Lang('dimensions')] = 'dimensions';
     $items[$mod->Lang('subscription')] = 'subscription';
     $items[$mod->Lang('quantity_on_hand')] = 'quantity';
+//     $cdmod = cms_utils::get_module('CompanyDirectory','1.19');
+//     if( is_object($cdmod) ) {
+//       $items[$mod->Lang('companydir_reference')] = 'companydir';
+//     }
     return array_flip($items);
   }
 
@@ -71,69 +72,60 @@ final class product_utils
     $fields = cge_array::to_hash($fields,'name');
     $fieldtype = $fields[$fieldname]['type'];
     $res = $fieldval;
-    switch( $fieldtype )
+    switch( $fieldtype ) {
+    case 'checkbox':
+      if( !is_null($res) ) $res = $mod->Lang('prompt_'.$res);
+      break;
+    case 'textarea':
+      $res = '';
+      break;
+    case 'dropdown':
+    case 'image':
+    case 'file':
+      break;
+    case 'dimensions':
       {
-      case 'checkbox':
-	if( !is_null($res) )
-	  $res = $mod->Lang('prompt_'.$res);
-	break;
-      case 'textarea':
-	$res = '';
-	break;
-      case 'dropdown':
-      case 'image':
-      case 'file':
-	break;
-      case 'dimensions':
-	{
-	  if( is_array($res) && $res['length'] > 0 && $res['width'] > 0 && $res['height'] > 0 )
-	    {
-	      $res = sprintf('%s: %d, %s: %d, %s: %d',
-			     $mod->Lang('abbr_length'),$res['length'],
-			     $mod->Lang('abbr_width'),$res['width'],
-			     $mod->Lang('abbr_height'),$res['height']);
-	    }
-	  else
-	    {
-	      $res = $mod->Lang('none');
-	    }
+	if( is_array($res) && $res['length'] > 0 && $res['width'] > 0 && $res['height'] > 0 ) {
+	  $res = sprintf('%s: %d, %s: %d, %s: %d',
+			 $mod->Lang('abbr_length'),$res['length'],
+			 $mod->Lang('abbr_width'),$res['width'],
+			 $mod->Lang('abbr_height'),$res['height']);
 	}
-	break;
-      case 'subscription':
-	{
-	  if( is_array($res) && $res['payperiod'] != -1 && $res['delperiod'] != -1 )
-	    {
-	      $subscribe_opts = array();
-	      $subscribe_opts[-1] = $mod->Lang('none');
-	      $subscribe_opts['monthly'] = $mod->Lang('subscr_monthly');
-	      $subscribe_opts['quarterly'] = $mod->Lang('subscr_quarterly');
-	      $subscribe_opts['semianually'] = $mod->Lang('subscr_semianually');
-	      $subscribe_opts['yearly'] = $mod->Lang('subscr_yearly');
-
-	      $expire_opts = array();
-	      $expire_opts[$mod->Lang('none')] = -1;
-	      $expire_opts[$mod->Lang('expire_six_month')] = '6';
-	      $expire_opts[$mod->Lang('expire_one_year')] = '12';
-	      $expire_opts[$mod->Lang('expire_two_year')] = '24';
-	      $expire_opts = array_flip($expire_opts);
-
-	      $expiry = 'none';
-	      if( $fieldval['expire'] != -1 )
-		{
-		  $expiry = $fieldval['expire'];
-		}
-	      $res = sprintf('%s: %s, %s: %s, %s: %s',
-			     $mod->Lang('subscr_payperiod2'),$fieldval['payperiod'],
-			     $mod->Lang('subscr_delperiod2'),$fieldval['delperiod'],
-			     $mod->Lang('subscr_expiry2'),$expiry);
-	    }
-	  else
-	    {
-	      $res = $mod->Lang('none');
-	    }
+	else {
+	  $res = $mod->Lang('none');
 	}
-	break;
       }
+      break;
+    case 'subscription':
+      {
+	if( is_array($res) && $res['payperiod'] != -1 && $res['delperiod'] != -1 ) {
+	  $subscribe_opts = array();
+	  $subscribe_opts[-1] = $mod->Lang('none');
+	  $subscribe_opts['monthly'] = $mod->Lang('subscr_monthly');
+	  $subscribe_opts['quarterly'] = $mod->Lang('subscr_quarterly');
+	  $subscribe_opts['semianually'] = $mod->Lang('subscr_semianually');
+	  $subscribe_opts['yearly'] = $mod->Lang('subscr_yearly');
+
+	  $expire_opts = array();
+	  $expire_opts[$mod->Lang('none')] = -1;
+	  $expire_opts[$mod->Lang('expire_six_month')] = '6';
+	  $expire_opts[$mod->Lang('expire_one_year')] = '12';
+	  $expire_opts[$mod->Lang('expire_two_year')] = '24';
+	  $expire_opts = array_flip($expire_opts);
+
+	  $expiry = 'none';
+	  if( $fieldval['expire'] != -1 ) $expiry = $fieldval['expire'];
+	  $res = sprintf('%s: %s, %s: %s, %s: %s',
+			 $mod->Lang('subscr_payperiod2'),$fieldval['payperiod'],
+			 $mod->Lang('subscr_delperiod2'),$fieldval['delperiod'],
+			 $mod->Lang('subscr_expiry2'),$expiry);
+	}
+	else {
+	  $res = $mod->Lang('none');
+	}
+      }
+      break;
+    }
 
     return $res;
   }
@@ -147,13 +139,9 @@ final class product_utils
     $out = array();
     foreach( $hierarchy_map as $onehier ) {
       if( $onehier['parent_id'] != $parent_id ) continue;
-      if( $callback_fn != '' && function_exists($callback_fn) ) {
-	$callback_fn($onehier);
-      }
+      if( $callback_fn != '' && function_exists($callback_fn) ) $callback_fn($onehier);
       $tmp = self::hierarchy_get_tree($onehier['id'],$showall,$callback_fn);
-      if( is_array($tmp) && count($tmp) ) {
-	$onehier['children'] = $tmp;
-      }
+      if( is_array($tmp) && count($tmp) ) $onehier['children'] = $tmp;
       $out[] = $onehier;
     }
     return $out;
@@ -167,68 +155,51 @@ final class product_utils
     $query = "SELECT id, item_order, name FROM ".cms_db_prefix()."module_products_hierarchy";
     $dbresult = $db->Execute($query);
     if( !$dbresult ) { echo $db->sql.'<br/>'; die( $db->ErrorMsg() ); }
-    while ($dbresult && $row = $dbresult->FetchRow())
-      {
-	$current_hierarchy_position = "";
-	$current_long_name = "";
-	$content_id = $row['id'];
-	$current_parent_id = $row['id'];
-	$count = 0;
-		
-	while ($current_parent_id > -1)
-	  {
-	    $query = "SELECT id, item_order, name, parent_id FROM ".cms_db_prefix()."module_products_hierarchy 
-                     WHERE id = ?";
-	    $row2 = $db->GetRow($query, array($current_parent_id));
-	    if ($row2)
-	      {
-		$current_hierarchy_position = str_pad($row2['item_order'], 5, '0', STR_PAD_LEFT) . "." . $current_hierarchy_position;
-		$current_long_name = $row2['name'] . ' | ' . $current_long_name;
-		$current_parent_id = $row2['parent_id'];
-		$count++;
-	      }
-	    else
-	      {
-		$current_parent_id = 0;
-	      }
+    while ($dbresult && $row = $dbresult->FetchRow()) {
+      $current_hierarchy_position = "";
+      $current_long_name = "";
+      $content_id = $row['id'];
+      $current_parent_id = $row['id'];
+      $count = 0;
 
-	  }
-		  
-	if (strlen($current_hierarchy_position) > 0)
-	  {
-	    $current_hierarchy_position = substr($current_hierarchy_position, 0, strlen($current_hierarchy_position) - 1);
-	  }
-		  
-	if (strlen($current_long_name) > 0)
-	  {
-	    $current_long_name = substr($current_long_name, 0, strlen($current_long_name) - 3);
-	  }
-	  
-	$query = "UPDATE ".cms_db_prefix()."module_products_hierarchy 
-                  SET hierarchy = ?, long_name = ? WHERE id = ?";
-	$db->Execute($query, array($current_hierarchy_position, $current_long_name, $content_id));
+      while ($current_parent_id > -1) {
+	$query = "SELECT id, item_order, name, parent_id FROM ".cms_db_prefix()."module_products_hierarchy 
+                  WHERE id = ?";
+	$row2 = $db->GetRow($query, array($current_parent_id));
+	if ($row2) {
+	  $current_hierarchy_position = str_pad($row2['item_order'], 5, '0', STR_PAD_LEFT) . "." . $current_hierarchy_position;
+	  $current_long_name = $row2['name'] . ' | ' . $current_long_name;
+	  $current_parent_id = $row2['parent_id'];
+	  $count++;
+	}
+	else {
+	  $current_parent_id = 0;
+	}
       }
+		  
+      if (strlen($current_hierarchy_position) > 0) {
+	$current_hierarchy_position = substr($current_hierarchy_position, 0, strlen($current_hierarchy_position) - 1);
+      }
+		  
+      if (strlen($current_long_name) > 0) $current_long_name = substr($current_long_name, 0, strlen($current_long_name) - 3);
+	  
+      $query = "UPDATE ".cms_db_prefix()."module_products_hierarchy 
+                SET hierarchy = ?, long_name = ? WHERE id = ?";
+      $db->Execute($query, array($current_hierarchy_position, $current_long_name, $content_id));
+    }
   }
 
 
   public static function hierarchy_save_tree($tree,$depth = 0,$update_hierarchy = TRUE)
   {
-    $query = 'UPDATE '.cms_db_prefix().'module_products_hierarchy 
-              SET parent_id = ?, item_order = ? WHERE id = ?';
+    $query = 'UPDATE '.cms_db_prefix().'module_products_hierarchy SET parent_id = ?, item_order = ? WHERE id = ?';
     $db = cmsms()->GetDb();
-    foreach( $tree as &$node )
-      {
-	$dbr = $db->Execute($query,array($node['parent_id'],$node['item_order'],$node['id']));
-	if( isset($node['children']) )
-	  {
-	    self::hierarchy_save_tree($node['children'],$depth+1);
-	  }
-      }
+    foreach( $tree as &$node ) {
+      $dbr = $db->Execute($query,array($node['parent_id'],$node['item_order'],$node['id']));
+      if( isset($node['children']) ) self::hierarchy_save_tree($node['children'],$depth+1);
+    }
 
-    if( $depth == 0 && $update_hierarchy )
-      {
-	self::update_hierarchy_positions();
-      }
+    if( $depth == 0 && $update_hierarchy ) self::update_hierarchy_positions();
   }
 
 
@@ -248,9 +219,7 @@ final class product_utils
       }
     }
 
-    if( !$by_name ) {
-      return self::$_category_cache;
-    }
+    if( !$by_name ) return self::$_category_cache;
 
     if( is_array(self::$_category_cache) ) {
       $out = array();
@@ -264,30 +233,29 @@ final class product_utils
   public static function get_full_categories($by_name = FALSE)
   {
     $categories = self::get_categories();
-    if( !is_array($categories) || count($categories) == 0 ) {
-      return;
-    }
+    if( !is_array($categories) || count($categories) == 0 ) return;
     
     $keys = array_keys($categories);
     $fid = $keys[0]; // first field.
     if( !isset(self::$_category_cache[$fid]->data) ) {
       // we're gonna use the same cache again...
       $db = cmsms()->GetDb();
+      $mod = cms_utils::get_module('Products');
+      $config = cmsms()->GetConfig();
       $query = 'SELECT * FROM '.cms_db_prefix().'module_products_category_fields ORDER BY category_id,field_order';
       $dbr = $db->GetArray($query);
       foreach( $keys as $one ) {
 	$cat =& self::$_category_cache[$one];
 	if( !isset($cat->data) ) $cat->data = array();
+	$cat->file_location = $config['uploads_url'].'/'.$mod->GetName().'/categories/'.$cat->id;
 	for( $i = 0; $i < count($dbr); $i++ ) {
-	  $catid = $dbr[$i]['category_id'];
-	  $cat->data[] = $dbr[$i];
+	  //$catid = $dbr[$i]['category_id'];
+	  if( $cat->id == $dbr[$i]['category_id'] )  $cat->data[] = $dbr[$i];
 	}
       }
     }
 
-    if( !$by_name ) {
-      return self::$_category_cache;
-    }
+    if( !$by_name ) return self::$_category_cache;
 
     if( is_array(self::$_category_cache) ) {
       $out = array();
@@ -338,9 +306,7 @@ final class product_utils
       self::$_flddef_cache = $entryarray;
     }
 
-    if( !$as_hash ) {
-      return self::$_flddef_cache;
-    }
+    if( !$as_hash ) return self::$_flddef_cache;
 
     $out = array();
     foreach( self::$_flddef_cache as $one ) {
