@@ -37,8 +37,8 @@
 
 class products_query implements ArrayAccess
 {
-  private static $_keys = array('productid','product_id','productlist','alias','category','categoryid','excludecat','hierarchy',
-								'hierarchyid','fieldid','fieldval','sortorder','sku','optsku',
+  private static $_keys = array('productid','product_id','productlist','alias','category','categoryid','excludecat',
+								'hierarchy','hierarchyid','fieldid','fieldval','sortorder','sku','optsku',
 								'sortby','sorttype','pagelimit','limit','page','status');
   private static $_sortings = array('id','product_name','price','create_date','modified','status','weight','random');
   private $_data = array();
@@ -67,26 +67,19 @@ class products_query implements ArrayAccess
 	$this->_data['page'] = 1;
 
     foreach( $this->_origparms as $key => $value ) {
-      if( in_array($key,self::$_keys) ) {
-		$this[$key] = $value;
-      }
+      if( in_array($key,self::$_keys) ) $this[$key] = $value;
     }
   }
 
   public function offsetGet($key)
   {
-    if( !in_array($key,self::$_keys) )
-      throw new ProductsException('Get: invalid key '.$key.' specified for products_query');
-
-    if( isset($this->_data[$key]) )
-      return $this->_data[$key];
+    if( !in_array($key,self::$_keys) ) throw new ProductsException('Get: invalid key '.$key.' specified for products_query');
+    if( isset($this->_data[$key]) ) return $this->_data[$key];
   }
 
   public function offsetSet($key,$value)
   {
-    if( !in_array($key,self::$_keys) )
-      throw new Exception('Set: Invalid Key '.$key.' specified for products_query');
-
+    if( !in_array($key,self::$_keys) ) throw new Exception('Set: Invalid Key '.$key.' specified for products_query');
     if( !$value ) return;
 
     $mod = cms_utils::get_module('Products');
@@ -140,7 +133,8 @@ class products_query implements ArrayAccess
       break;
       
     case 'productlist':
-      $tmp = explode(',',$value);
+	  $tmp = $value;
+	  if( is_string($value) ) $tmp = explode(',',$value);
       if( is_array($tmp) && count($tmp) ) {
 		foreach( $tmp as &$one ) {
 		  $one = (int)$one;
@@ -196,15 +190,32 @@ class products_query implements ArrayAccess
 
     case 'sortby':
       $value = strtolower(trim($value));
-      if( in_array($value,self::$_sortings) ) {
+	  switch( $value ) {
+	  case 'id':
+	  case 'product_name':
+	  case 'price':
+	  case 'weight':
+	  case 'status':
+	  case 'random':
+	  case 'create_date':
+	  case 'modified':
 		$this->_data[$key] = $value;
-      } else if( startswith($value,'f:') ) {
-		$fieldname = substr($value,strlen('f:'));
- 		$fielddefs = product_utils::get_fielddefs(FALSE,TRUE,TRUE);
- 		if( is_array($fielddefs) && isset($fielddefs[$fieldname]) ) {
- 		  $this->_data[$key] = $value;
- 		}
-      }
+		break;
+		
+	  case 'created':
+		$this->_data[$key] = 'create_date';
+		break;
+
+	  default:
+		if( startswith($value,'f:') ) {
+		  $fieldname = substr($value,strlen('f:'));
+		  $fielddefs = product_utils::get_fielddefs(FALSE,TRUE,TRUE);
+		  if( is_array($fielddefs) && isset($fielddefs[$fieldname]) ) $this->_data[$key] = $value;
+		}
+		else {
+		  throw new ProductsException('Set: invalid sorting '.$value);
+		}
+	  }
       break;
 
     case 'sorttype':
@@ -235,17 +246,13 @@ class products_query implements ArrayAccess
 
   public function offsetExists($key)
   {
-    if( !in_array($key,self::$_keys) )
-      throw new ProductsException('Exists: Invalid Key '.$key.' specified for products_query');
-
+    if( !in_array($key,self::$_keys) ) throw new ProductsException('Exists: Invalid Key '.$key.' specified for products_query');
     return isset($this->_data[$key]);
   }
 
   public function offsetUnset($key)
   {
-    if( !in_array($key,self::$_keys) )
-      throw new ProductsException('Exists: Invalid Key '.$key.' specified for products_query');
-
+    if( !in_array($key,self::$_keys) ) throw new ProductsException('Unset: Invalid Key '.$key.' specified for products_query');
     return FALSE;
   }
 
