@@ -87,12 +87,9 @@ final class products_resultset
 	  $where[] = 'C.id = ?';
 	  $qparms[] = $pid;
 	}
-
 	else if( isset($obj['productlist']) && $obj['productlist'] != '' ) {
 	  $tmp = $obj['productlist'];
-	  if( !is_array($tmp) ) {
-		$tmp = explode(',',$tmp);
-	  }
+	  if( !is_array($tmp) ) $tmp = explode(',',$tmp);
 	  $list = array();
 	  foreach( $tmp as $one ) {
 		$one = (int)$one;
@@ -113,12 +110,6 @@ final class products_resultset
 	  $qparms[] = $val;
 	}
 
-    if( isset($obj['categoryid']) && $obj['categoryid'] != '' ) {
-      $joins[] = cms_db_prefix().'module_products_categories cc ON cc.product_id = C.id';
-      $where[] = 'cc.category_id = ?';
-      $qparms[] = $obj['categoryid'];
-    }
-
 	if( isset($obj['hierarchy']) && $obj['hierarchy'] != '' ) {
 	  $subquery = 'SELECT DISTINCT id FROM '.cms_db_prefix().'module_products_hierarchy h WHERE ';
 	  $subparms = array();
@@ -140,8 +131,8 @@ final class products_resultset
 	  $hierarchy_ids = $db->GetCol($subquery,$subparms);
 
 	  if( is_array($hierarchy_ids) && count($hierarchy_ids) ) {
-		$joins[] = cms_db_prefix().'module_products_prodtohier ph ON ph.product_id = C.id';
-		$where[] = 'ph.hierarchy_id IN ('.implode(',',$hierarchy_ids).')';
+		//$joins[] = cms_db_prefix().'module_products_prodtohier ph ON ph.product_id = C.id';
+		$where[] = 'PH.hierarchy_id IN ('.implode(',',$hierarchy_ids).')';
 	  }
 	}
 	else if( isset($obj['hierarchyid']) ) {
@@ -157,9 +148,7 @@ final class products_resultset
 		$icatids = array();
 		foreach( $icats as $one ) {
 		  $one = trim($one);
-		  if( isset($ocats[$one]) ) {
-			$icatids[] = (int)$ocats[$one]->id;
-		  }
+		  if( isset($ocats[$one]) ) $icatids[] = (int)$ocats[$one]->id;
 		}
 		if( count($icatids) ) {
 		  $joins[] = cms_db_prefix().'module_products_product_categories cc ON cc.product_id = C.id';
@@ -167,22 +156,29 @@ final class products_resultset
 		}
       }
     }
+    else if( isset($obj['categoryid']) && $obj['categoryid'] != '' ) {
+      $joins[] = cms_db_prefix().'module_products_product_categories pc ON pc.product_id = C.id';
+      $where[] = 'pc.category_id = ?';
+      $qparms[] = $obj['categoryid'];
+    }
 
     if( isset($obj['excludecat']) && $obj['excludecat'] != '' ) {
       // get the cateogry id's from the name.
       $ocats = product_utils::get_categories(TRUE);
 	  $ecats = explode(',',$obj['excludecat']);
 	  $exclude_ids = array();
-	  foreach( $icats as $ecat ) {
-		if( is_numeric($ecat) ) {
-		  $exclude_ids = (int)$ecat;
+	  foreach( $ecats as $ecat ) {
+		if( (int)$ecat > 0 ) {
+		  $exclude_ids[] = (int)$ecat;
 		}
 		else {
-		  if( isset($ocats[$ecat]) ) {
-			$exclude_ids = (int)$ocats[$cat]['id'];
-		  }
+		  if( isset($ocats[$ecat]) ) $exclude_ids[] = (int)$ocats[$ecat]->id;
 		}
 	  }
+	  if( count($exclude_ids) ) {
+		$joins[] = cms_db_prefix().'module_products_product_categories cc ON cc.product_id = C.id';
+		$where[] = 'cc.category_id NOT IN ('.implode(',',$exclude_ids).')';
+	  }
     }
 
 	if( isset($obj['fieldid']) && $obj['fieldid'] > 0 && isset($obj['fieldval']) && $obj['fieldval'] != '' ) {
@@ -204,9 +200,16 @@ final class products_resultset
 	  else {
 		// limit results to all of the items that have this field, and field value.
 		$joins[] = cms_db_prefix().'module_products_fieldvals FVA ON C.id = FVA.product_id AND FVA.fielddef_id = ?';
-		$where[] = '(FVA.value = ?)';
-		array_unshift($qparms,$fieldid);
-		$qparms[] = $fieldval;
+		if( strpos($fieldval,'*') !== FALSE || strpos($fieldval,'%') !== FALSE ) {
+		  $where[] = '(FVA.value LIKE ?)';
+		  array_unshift($qparms,$fieldid);
+		  $qparms[] = str_replace('*','%',$fieldval);
+		}
+		else {
+		  $where[] = '(FVA.value = ?)';
+		  array_unshift($qparms,$fieldid);
+		  $qparms[] = $fieldval;
+		}
 	  }
 	}
 
@@ -231,12 +234,8 @@ final class products_resultset
 	//
 	// build the query now.
 	//
-	if( count($joins) ) {
-	  $query .= ' LEFT JOIN '.implode(' LEFT JOIN ',$joins);
-	}
-	if( count($where) ) {
-	  $query .= ' WHERE '.implode(' AND ',$where);
-	}
+	if( count($joins) ) $query .= ' LEFT JOIN '.implode(' LEFT JOIN ',$joins);
+	if( count($where) ) $query .= ' WHERE '.implode(' AND ',$where);
 	if( $obj['sorttype'] == '' ) {
 	  $query .= ' ORDER BY '.$sortby.' '.$obj['sortorder'];
 	}
@@ -251,9 +250,7 @@ final class products_resultset
 	  $startelement = ((int)$obj['page'] - 1) * $limit;
 	}
 	$this->_rs = $db->SelectLimit($query,$limit,$startelement,$qparms);
-	if( !$this->_rs ) {
-	  throw new Exception('INTERNAL ERROR: Query failed - '.$db->sql.' -- '.$db->ErrorMsg());
-	}
+	if( !$this->_rs ) throw new Exception('INTERNAL ERROR: Query failed - '.$db->sql.' -- '.$db->ErrorMsg());
 	$this->_totalmatchingrows = $db->GetOne('SELECT FOUND_ROWS()');
 
 	$this->_preload();
@@ -303,9 +300,7 @@ final class products_resultset
 	  $oneset =& $attribs[$i];
 	  $pid = $oneset['product_id'];
 	  if( !isset($this->_attribute_cache[$pid]) ) $this->_attribute_cache[$pid] = array();
-	  $data =& $this->_attribute_cache[$pid];
-
-	  $data[] = $oneset;
+	  $this->_attribute_cache[$pid][] = $oneset;
 	}
   }
 
@@ -327,15 +322,11 @@ final class products_resultset
 
 	// preload category info for proudct(s).
 	$allcats = product_utils::get_categories(TRUE);
-	if( is_array($allcats) && count($allcats) ) {
-	  $this->_preload_categories($product_ids);
-	}
+	if( is_array($allcats) && count($allcats) ) $this->_preload_categories($product_ids);
 
 	// preload field info
 	$allfields = product_utils::get_fielddefs(TRUE,TRUE);
-	if( is_array($allfields) && count($allfields) ) {
-	  $this->_preload_fields($product_ids);
-	}
+	if( is_array($allfields) && count($allfields) ) $this->_preload_fields($product_ids);
 
 	// preload attributes
 	$this->_preload_attributes($product_ids);
@@ -399,9 +390,7 @@ final class products_resultset
 	  if( $this->_curpage ) return $this->_curpage;
 	  return cmsms()->GetContentOperations()->GetDefaultContent();
 	}
-	if( $key == 'detailtemplate' ) {
-	  return $this->_detailtemplate;
-	}
+	if( $key == 'detailtemplate' ) return $this->_detailtemplate;
 	if( $key == 'hierpage' ) {
 	  if( $this->_hierpage ) return $this->_hierpage;
 	  $dfltreturnid = $mod->GetPreference('hierpage',-1);
@@ -409,26 +398,14 @@ final class products_resultset
 	  if( $this->_curpage ) return $this->_curpage;
 	  return cmsms()->GetContentOperations()->GetDefaultContent();
 	}
-	if( $key == 'curpage' ) {
-	  return $this->_curpage;
-	}
-	if( $key == 'notpretty' ) {
-	  return $this->_notpretty;
-	}
+	if( $key == 'curpage' ) return $this->_curpage;
+	if( $key == 'notpretty' ) return $this->_notpretty;
 
 	$this->_execute();
-	if( $key == 'EOF' ) {
-	  return $this->_rs->EOF();
-	}
-	if( $key == 'totalrows' ) {
-	  return $this->_totalmatchingrows;
-	}
-	if( $key == 'fields' && $this->_rs && !$this->_rs->EOF() ) {
-	  return $this->_rs->fields;
-	}
-	if( $key == 'numpages' ) {
-	  return ceil($this->_totalmatchingrows / $this->_query['pagelimit']);
-	}
+	if( $key == 'EOF' ) return $this->_rs->EOF();
+	if( $key == 'totalrows' ) return $this->_totalmatchingrows;
+	if( $key == 'fields' && $this->_rs && !$this->_rs->EOF() ) return $this->_rs->fields;
+	if( $key == 'numpages' ) return ceil($this->_totalmatchingrows / $this->_query['pagelimit']);
   }
 
   public function __set($key,$value)
@@ -452,9 +429,7 @@ final class products_resultset
 	  break;
 	case 'detailtemplate':
 	  $this->_detailtemplate = $value;
-	  if( $this->_notpretty == '' ) {
-		$this->_notpretty = 'details';
-	  }
+	  if( $this->_notpretty == '' ) $this->_notpretty = 'details';
 	  break;
 
 	default:
